# smart-commit
A python CLI tool to generate git commit messages using [OpenAI](https://openai.com/blog/openai-codex/)

> This project is actively underdevelopment.

## How to use it

1. Setup your OpenAI account and grab an API key from your [dashboard](https://openai.com/api/)
2. Save that API key as env variable 

  ```
    export OPENAI_API_KEY='sk-********'
  ```
3. Install all dependencies

  ```
  pip install requirements.txt
  ```
4. Run smartcommit.py file

  ```
  python smartcommit.py
  ```
## TODO

- [ ] pip installer
- [ ] Error handling
